
#line 3 "<stdout>"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define yy_create_buffer HECMW_hec_create_buffer
#define yy_delete_buffer HECMW_hec_delete_buffer
#define yy_flex_debug HECMW_hec_flex_debug
#define yy_init_buffer HECMW_hec_init_buffer
#define yy_flush_buffer HECMW_hec_flush_buffer
#define yy_load_buffer_state HECMW_hec_load_buffer_state
#define yy_switch_to_buffer HECMW_hec_switch_to_buffer
#define yyin HECMW_hecin
#define yyleng HECMW_hecleng
#define yylex HECMW_heclex
#define yylineno HECMW_heclineno
#define yyout HECMW_hecout
#define yyrestart HECMW_hecrestart
#define yytext HECMW_hectext
#define yywrap HECMW_hecwrap
#define yyalloc HECMW_hecalloc
#define yyrealloc HECMW_hecrealloc
#define yyfree HECMW_hecfree

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 5
#define YY_FLEX_SUBMINOR_VERSION 35
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
typedef uint64_t flex_uint64_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;
#endif /* ! C99 */

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#endif /* ! FLEXINT_H */

#ifdef __cplusplus

/* The "const" storage-class-modifier is valid. */
#define YY_USE_CONST

#else	/* ! __cplusplus */

/* C99 requires __STDC__ to be defined as 1. */
#if defined (__STDC__)

#define YY_USE_CONST

#endif	/* defined (__STDC__) */
#endif	/* ! __cplusplus */

#ifdef YY_USE_CONST
#define yyconst const
#else
#define yyconst
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an unsigned
 * integer for use as an array index.  If the signed char is negative,
 * we want to instead treat it as an 8-bit unsigned char, hence the
 * double cast.
 */
#define YY_SC_TO_UI(c) ((unsigned int) (unsigned char) c)

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN (yy_start) = 1 + 2 *

/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START (((yy_start) - 1) / 2)
#define YYSTATE YY_START

/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)

/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE HECMW_hecrestart(HECMW_hecin  )

#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#define YY_BUF_SIZE 16384
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

extern yy_size_t HECMW_hecleng;

extern FILE *HECMW_hecin, *HECMW_hecout;

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2

    #define YY_LESS_LINENO(n)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up HECMW_hectext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = (yy_hold_char); \
		YY_RESTORE_YY_MORE_OFFSET \
		(yy_c_buf_p) = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up HECMW_hectext again */ \
		} \
	while ( 0 )

#define unput(c) yyunput( c, (yytext_ptr)  )

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	yy_size_t yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	yy_size_t yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */
    
	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via HECMW_hecrestart()), so that the user can continue scanning by
	 * just pointing HECMW_hecin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* Stack of input buffers. */
static size_t yy_buffer_stack_top = 0; /**< index of top of stack. */
static size_t yy_buffer_stack_max = 0; /**< capacity of stack. */
static YY_BUFFER_STATE * yy_buffer_stack = 0; /**< Stack as an array. */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( (yy_buffer_stack) \
                          ? (yy_buffer_stack)[(yy_buffer_stack_top)] \
                          : NULL)

/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE (yy_buffer_stack)[(yy_buffer_stack_top)]

/* yy_hold_char holds the character lost when HECMW_hectext is formed. */
static char yy_hold_char;
static yy_size_t yy_n_chars;		/* number of characters read into yy_ch_buf */
yy_size_t HECMW_hecleng;

/* Points to current character in buffer. */
static char *yy_c_buf_p = (char *) 0;
static int yy_init = 0;		/* whether we need to initialize */
static int yy_start = 0;	/* start state number */

/* Flag which is used to allow HECMW_hecwrap()'s to do buffer switches
 * instead of setting up a fresh HECMW_hecin.  A bit of a hack ...
 */
static int yy_did_buffer_switch_on_eof;

void HECMW_hecrestart (FILE *input_file  );
void HECMW_hec_switch_to_buffer (YY_BUFFER_STATE new_buffer  );
YY_BUFFER_STATE HECMW_hec_create_buffer (FILE *file,int size  );
void HECMW_hec_delete_buffer (YY_BUFFER_STATE b  );
void HECMW_hec_flush_buffer (YY_BUFFER_STATE b  );
void HECMW_hecpush_buffer_state (YY_BUFFER_STATE new_buffer  );
void HECMW_hecpop_buffer_state (void );

static void HECMW_hecensure_buffer_stack (void );
static void HECMW_hec_load_buffer_state (void );
static void HECMW_hec_init_buffer (YY_BUFFER_STATE b,FILE *file  );

#define YY_FLUSH_BUFFER HECMW_hec_flush_buffer(YY_CURRENT_BUFFER )

YY_BUFFER_STATE HECMW_hec_scan_buffer (char *base,yy_size_t size  );
YY_BUFFER_STATE HECMW_hec_scan_string (yyconst char *yy_str  );
YY_BUFFER_STATE HECMW_hec_scan_bytes (yyconst char *bytes,yy_size_t len  );

void *HECMW_hecalloc (yy_size_t  );
void *HECMW_hecrealloc (void *,yy_size_t  );
void HECMW_hecfree (void *  );

#define yy_new_buffer HECMW_hec_create_buffer

#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        HECMW_hecensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            HECMW_hec_create_buffer(HECMW_hecin,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}

#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        HECMW_hecensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            HECMW_hec_create_buffer(HECMW_hecin,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}

#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* Begin user sect3 */

typedef unsigned char YY_CHAR;

FILE *HECMW_hecin = (FILE *) 0, *HECMW_hecout = (FILE *) 0;

typedef int yy_state_type;

extern int HECMW_heclineno;

int HECMW_heclineno = 1;

extern char *HECMW_hectext;
#define yytext_ptr HECMW_hectext

static yy_state_type yy_get_previous_state (void );
static yy_state_type yy_try_NUL_trans (yy_state_type current_state  );
static int yy_get_next_buffer (void );
static void yy_fatal_error (yyconst char msg[]  );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up HECMW_hectext.
 */
#define YY_DO_BEFORE_ACTION \
	(yytext_ptr) = yy_bp; \
	HECMW_hecleng = (yy_size_t) (yy_cp - yy_bp); \
	(yy_hold_char) = *yy_cp; \
	*yy_cp = '\0'; \
	(yy_c_buf_p) = yy_cp;

#define YY_NUM_RULES 99
#define YY_END_OF_BUFFER 100
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static yyconst flex_int16_t yy_accept[544] =
    {   0,
        0,    0,    0,    5,    0,    0,  100,   98,    8,    9,
       98,   98,   98,   91,   97,   95,   97,   94,   90,   96,
       96,   92,   96,   96,   96,   96,   96,   96,   96,   96,
       93,   96,   96,   96,   96,   98,   98,   99,    2,   99,
       99,    5,    5,    4,    5,    6,   98,    8,    9,    0,
        0,    0,    0,    0,    0,    0,    0,   95,   94,   97,
       95,   94,   95,   97,   96,    0,   96,   96,   96,   96,
       96,   96,   96,   96,   96,   96,   96,   96,   96,   96,
       96,   96,   96,   96,   96,   96,   96,   96,   96,   96,
       96,   96,    0,    0,    0,    0,    0,    0,    0,    0,

        0,    0,    0,    7,    0,    2,    0,    5,    4,    4,
        4,    5,    1,    5,    6,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,   95,    0,    0,   97,   95,   97,   96,
       96,   96,   96,   96,   96,   96,   96,   96,   96,   96,
       96,   96,   96,   96,   96,   96,   96,   96,   96,   96,
       96,   96,   96,   96,   96,   96,   96,   96,   96,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    4,
        4,    4,    0,    0,    0,    0,    0,    0,   25,    0,

        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,   95,   96,   96,   57,   96,   96,   60,
       96,   96,   96,   96,   65,   96,   96,   68,   96,   70,
       96,   96,   96,   96,   75,   96,   96,   96,   96,   96,
       96,   96,   96,   96,   85,   86,   96,    0,    0,    0,
        0,    0,    0,   24,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        4,    0,    0,    0,    0,   19,    0,    0,    0,    0,
        0,   34,    0,    0,    0,   42,    0,   46,    0,    0,
        0,   54,   96,   96,   96,   96,   96,   62,   63,   96,

       96,   96,   96,   96,   96,   96,   96,   76,   77,    0,
       96,   96,   96,   96,   82,   96,   96,   96,   87,    0,
        0,    0,    0,   18,    0,    0,    0,    0,    0,    0,
       33,    0,    0,    0,   41,    0,   45,    0,    0,    0,
       53,    0,    4,    0,    0,    0,   17,    0,    0,    0,
        0,    0,    0,   38,   40,    0,    0,    0,    0,   55,
       96,   96,   96,   96,   96,   96,   96,   96,   96,   96,
       73,   96,    0,   96,   96,   96,   81,   96,   96,   96,
       96,    0,    0,    0,   16,    0,    0,    0,    0,    0,
        0,    0,   37,   39,    0,    0,    0,    0,    0,    4,

        0,    0,    0,   21,    0,    0,    0,    0,    0,   44,
        0,   50,   52,   96,   96,   96,   96,   96,   96,   67,
       69,   96,   96,   74,    0,   96,   79,   96,   83,   96,
       96,   96,    0,    0,    0,   20,    0,    0,   28,    0,
        0,    0,   43,    0,   49,   51,    3,    3,    0,    0,
        0,   23,    0,   30,    0,    0,   48,   56,   96,   96,
       61,   96,   66,   96,   72,    0,   78,   96,   96,   96,
       96,    0,    0,    0,   22,    0,   29,    0,    0,   47,
        3,    3,    0,    0,    0,    0,   27,    0,    0,   36,
       58,   96,   64,   71,   78,   80,   96,   88,   89,    0,

        0,    0,    0,   26,    0,    0,   35,   11,    0,    0,
        0,   59,   96,   10,    0,    0,    0,    0,    0,    0,
       84,    0,    0,    0,    0,   15,    0,    0,   14,    0,
       13,    0,   12,    0,    0,    0,    0,    0,    0,    0,
       32,   31,    0
    } ;

static yyconst flex_int32_t yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        1,    1,    4,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    5,    6,    1,    7,    1,    1,    1,    1,    1,
        1,    1,    8,    9,   10,   11,   12,   13,   13,   13,
       13,   13,   13,   13,   13,   13,   13,   14,    1,    1,
       15,    1,    1,    1,   16,   17,   18,   19,   20,   21,
       22,   23,   24,   25,   25,   26,   27,   28,   29,   30,
       31,   32,   33,   34,   35,   36,   37,   25,   38,   39,
        1,   12,    1,    1,   40,    1,   25,   25,   25,   25,

       41,   25,   25,   25,   25,   25,   25,   25,   25,   25,
       25,   25,   25,   25,   25,   25,   25,   25,   25,   25,
       25,   25,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static yyconst flex_int32_t yy_meta[42] =
    {   0,
        1,    1,    2,    1,    1,    1,    1,    1,    1,    3,
        3,    3,    3,    4,    1,    3,    3,    3,    3,    3,
        3,    3,    3,    3,    3,    3,    3,    3,    3,    3,
        3,    3,    3,    3,    3,    3,    3,    3,    3,    3,
        3
    } ;

static yyconst flex_int16_t yy_base[556] =
    {   0,
        0,   36,   41,   45,   50,   52, 1162, 1225,   55, 1225,
     1152,   45,   51, 1225,   55,   54,    0,   64, 1225,   68,
       76,   80,   86,   90,   96,  102,  106,  113,  117,  123,
      137,  147,  175,  152,  132,  208,   67, 1225, 1225, 1150,
     1126,    0, 1142,   70,  150, 1225, 1140,   81, 1225, 1109,
     1105,  162,   71, 1116,  176,  118, 1104,  142,  108,    0,
      159,  119,  188,  165,  192,  199,  204,  211,  231,  238,
      242,  249,  253,  258,  264,  268,  279,  275,  284,  297,
      302,  307,  313,  317,  324,  334,  338,  342,  346,  350,
      356,  364,  230, 1093, 1083,  361, 1088,  108, 1087,  373,

      224, 1081,  296, 1225,  301, 1225, 1077,    0,    0,  337,
     1073,  377, 1225,  381, 1225, 1059, 1056, 1054,   83, 1060,
     1059, 1039,  147, 1050, 1034, 1035, 1036,   91, 1037, 1034,
     1012, 1009, 1006,  253,  324, 1023, 1019, 1012, 1009,  385,
      389,  393,  397,  401,  410,  417,  421,  427,  431,  438,
      443,  457,  447,  461,  468,  473,  481,  486,  491,  495,
      500,  509,  513,  517,  524,  528,  532,  542,  549,  989,
      987,  981,  187,  986,  983,  964,  981,  178,  973,  950,
      953,  956,  265,  957,  956,  938,  935,  920,  930,  443,
      544,  926,  911,  223,  902,  900,  895,  890, 1225,  898,

      886,  872,  876,  881,  865,  865,  856,  853,  858,  840,
      843,  834,  834,  848,  553,  557,  561,  565,  575,  579,
      584,  588,  593,  597,  601,  606,  610,  619,  623,  628,
      635,  639,  645,  650,  654,  658,  666,  676,  680,  685,
      689,  693,  704,  708,  712,  720,  724,  833,  335,  825,
      823,  819,  817, 1225,  824,  818,  809,  796,  802,  808,
      796,  795,  789,  786,  791,  773,  774,  765,  764,  773,
      771,  762,  765,  767,  741, 1225,  740,  751,  735,  728,
      734, 1225,  724,  714,  719, 1225,  708, 1225,  717,  702,
      713, 1225,  728,  735,  739,  743,  748,  754,  762,  766,

      770,  777,  784,  790,  794,  798,  802,  808,  813,  695,
      822,  827,  831,  838,  842,  846,  855,  859,  865,  703,
      705,  705,  679, 1225,  677,  691,  674,  686,  667,  674,
     1225,  661,  651,  660, 1225,  648, 1225,  658,  644,  656,
     1225,  651,  647,  629,  642,  640, 1225,  624,  624,  624,
      624,  625,  612, 1225, 1225,  602,  599,  596,  596,  869,
      874,  878,  882,  886,  893,  899,  907,  911,  915,  919,
      924,  929,  595,  933,  937,  942,  947,  951,  955,  961,
      967,  580,  592,  588, 1225,  571,  569,  568,  553,  563,
      565,  556, 1225, 1225,  548,  545,  540,  539,  525,  523,

      514,  511,  507, 1225,  503,  503,  506,  496,  502, 1225,
      485, 1225, 1225,  974,  978,  984,  989,  993, 1002, 1006,
     1010, 1015, 1019, 1023,  481, 1029, 1034, 1039, 1043, 1047,
     1051, 1055,  469,  467,  465, 1225,  462,  465, 1225,  470,
      460,  467, 1225,  450, 1225, 1225,    0,    0,  457,  450,
      187, 1225,  442, 1225,  250,  440, 1225, 1061, 1065, 1076,
     1080, 1084, 1088, 1095, 1099,  444, 1103, 1107, 1111, 1115,
     1119,  441,  432,  296, 1225,  425, 1225,  312,  418, 1225,
        0,    0,  416,  398,  400,  410, 1225,  405,  390, 1225,
     1126, 1130, 1136, 1140, 1225, 1145, 1149, 1153, 1157,  397,

      378,  380,  390, 1225,  380,  364, 1225, 1225,  364,  358,
      346, 1161, 1165, 1225,  348,  341,  327,  313,  310,  303,
     1172,  281,  278,  264,  243, 1225,  224,  202, 1225,  214,
     1225,  196, 1225,  187,  153,  150,  131,  121,   61,   53,
     1225, 1225, 1225, 1186, 1190,   47, 1192, 1196, 1200, 1204,
     1208,   43, 1212, 1216, 1220
    } ;

static yyconst flex_int16_t yy_def[556] =
    {   0,
      543,    1,  544,  545,    1,    1,  543,  543,  543,  543,
      543,  543,  543,  543,  546,  546,  546,  546,  543,  547,
      547,  547,  547,  547,  547,  547,  547,  547,  547,  547,
      547,  547,  547,  547,  547,  543,  548,  543,  543,  543,
      543,  549,  549,  550,  551,  543,  543,  543,  543,  543,
      543,  543,  543,  543,  543,  543,  543,  543,  543,  546,
      546,  546,  546,  546,  547,  552,  547,  547,  547,  547,
      547,  547,  547,  547,  547,  547,  547,  547,  547,  547,
      547,  547,  547,  547,  547,  547,  547,  547,  547,  547,
      547,  547,  548,  543,  543,  543,  543,  543,  543,  543,

      543,  543,  548,  543,  548,  543,  543,  549,  550,  553,
      550,  551,  543,  551,  543,  543,  543,  543,  543,  543,
      543,  543,  543,  543,  543,  543,  543,  543,  543,  543,
      543,  543,  543,  543,  543,  543,  546,  546,  546,  547,
      547,  547,  547,  547,  547,  547,  547,  547,  547,  547,
      547,  547,  547,  547,  547,  547,  547,  547,  547,  547,
      547,  547,  547,  547,  547,  547,  547,  547,  547,  543,
      543,  543,  543,  543,  543,  543,  543,  543,  543,  543,
      543,  543,  543,  543,  543,  543,  543,  543,  543,  553,
      553,  550,  543,  543,  543,  543,  543,  543,  543,  543,

      543,  543,  543,  543,  543,  543,  543,  543,  543,  543,
      543,  543,  543,  543,  547,  547,  547,  547,  547,  547,
      547,  547,  547,  547,  547,  547,  547,  547,  547,  547,
      547,  547,  547,  547,  547,  547,  547,  547,  547,  547,
      547,  547,  547,  547,  547,  547,  547,  543,  543,  543,
      543,  543,  543,  543,  543,  543,  543,  543,  543,  543,
      543,  543,  543,  543,  543,  543,  543,  543,  543,  543,
      550,  543,  543,  543,  543,  543,  543,  543,  543,  543,
      543,  543,  543,  543,  543,  543,  543,  543,  543,  543,
      543,  543,  547,  547,  547,  547,  547,  547,  547,  547,

      547,  547,  547,  547,  547,  547,  547,  547,  547,  543,
      547,  547,  547,  547,  547,  547,  547,  547,  547,  543,
      543,  543,  543,  543,  543,  543,  543,  543,  543,  543,
      543,  543,  543,  543,  543,  543,  543,  543,  543,  543,
      543,  543,  550,  543,  543,  543,  543,  543,  543,  543,
      543,  543,  543,  543,  543,  543,  543,  543,  543,  547,
      547,  547,  547,  547,  547,  547,  547,  547,  547,  547,
      547,  547,  543,  547,  547,  547,  547,  547,  547,  547,
      547,  543,  543,  543,  543,  543,  543,  543,  543,  543,
      543,  543,  543,  543,  543,  543,  543,  543,  543,  550,

      543,  543,  543,  543,  543,  543,  543,  543,  543,  543,
      543,  543,  543,  547,  547,  547,  547,  547,  547,  547,
      547,  547,  547,  547,  543,  547,  547,  547,  547,  547,
      547,  547,  543,  543,  543,  543,  543,  543,  543,  543,
      543,  543,  543,  543,  543,  543,  554,  555,  543,  543,
      543,  543,  543,  543,  543,  543,  543,  547,  547,  547,
      547,  547,  547,  547,  547,  543,  547,  547,  547,  547,
      547,  543,  543,  543,  543,  543,  543,  543,  543,  543,
      554,  555,  543,  543,  543,  543,  543,  543,  543,  543,
      547,  547,  547,  547,  543,  547,  547,  547,  547,  543,

      543,  543,  543,  543,  543,  543,  543,  543,  543,  543,
      543,  547,  547,  543,  543,  543,  543,  543,  543,  543,
      547,  543,  543,  543,  543,  543,  543,  543,  543,  543,
      543,  543,  543,  543,  543,  543,  543,  543,  543,  543,
      543,  543,    0,  543,  543,  543,  543,  543,  543,  543,
      543,  543,  543,  543,  543
    } ;

static yyconst flex_int16_t yy_nxt[1267] =
    {   0,
        8,    9,   10,   11,    9,   12,    8,   13,   14,   15,
       16,   17,   18,    8,   19,   20,   21,   22,   23,   24,
       25,   26,   27,   28,   25,   25,   29,   30,   25,   25,
       25,   31,   32,   33,   25,   34,   25,   25,   25,   35,
       25,   36,   37,   39,   40,  139,   41,   39,   43,   60,
       44,   45,   46,   47,   46,   47,   48,   36,   37,   48,
       50,   58,   51,   59,   52,   61,   63,   62,   53,  104,
      105,   54,   55,   64,   61,  110,   62,   56,   60,   60,
      542,   66,   48,   57,   67,   48,   60,   60,  541,   66,
       60,   60,  111,   66,   64,   68,   60,   60,  123,   66,

       60,   60,  196,   66,  124,   70,   60,   60,   69,   66,
      207,   71,   60,   60,  197,   66,   60,   60,   58,   66,
       59,   72,  208,   60,   60,   73,   66,   60,   60,   61,
       66,   62,   76,   60,   60,  178,   66,  130,   77,  131,
       74,  179,   60,   60,   78,  543,   75,   60,   60,  540,
       66,   79,  113,  114,  134,  132,   80,   60,   60,  539,
       66,  135,   60,   60,  201,   66,   81,   92,   82,   83,
      202,   63,  136,  538,  137,   84,  537,  138,   64,  118,
       85,   86,  135,  119,   87,   60,   60,  120,   66,  121,
       88,  485,  122,  126,   89,  257,  127,  128,   90,   64,

       63,  258,   60,   60,  129,  543,  251,   64,   60,   60,
       60,   60,   91,   93,   60,   60,  486,  543,  252,  140,
      536,   60,   60,   94,  543,   95,  142,   96,   64,  535,
       97,   98,  104,  105,   99,  100,  141,  534,   60,  533,
      101,   60,   60,  185,  543,  186,  102,  532,   60,   60,
      273,  543,   60,   60,  488,  543,  274,  143,  144,   60,
       60,  187,  543,   60,   60,  134,  543,  489,   60,   60,
      147,  543,  135,  145,   60,   60,  146,  543,   60,   60,
      531,  543,  530,  150,  263,   60,   60,  148,  543,   60,
       60,  149,  543,  135,   60,   60,  264,  543,  104,  105,

      502,  151,  155,  104,  105,  152,  154,   60,   60,  529,
      543,  153,   60,   60,  528,  543,  505,   60,   60,  157,
      543,  527,  156,   60,   60,  503,  543,   60,   60,  506,
      543,  136,  159,  136,   60,   60,  214,  543,  158,  113,
      191,  526,  160,  161,   60,   60,  525,  543,   60,   60,
      162,  543,   60,   60,  524,  543,   60,   60,  165,  543,
       60,   60,  321,  543,  523,  163,   60,   60,  322,  543,
      164,  522,  166,  520,   60,   60,  167,  543,  172,  113,
      114,  519,  173,  113,  114,  168,  174,  518,  175,  169,
      181,  176,  517,  182,  183,   60,   60,  506,  543,   60,

       60,  184,  543,   60,   60,  516,  543,   60,   60,  503,
      543,   60,   60,  515,  543,  215,  514,  216,  511,  217,
       60,   60,  489,  543,  219,  510,  218,   60,   60,  486,
      543,   60,   60,  509,  543,  508,  221,   60,   60,  220,
      543,   60,   60,  507,  543,  113,  191,  222,   60,   60,
      224,  543,  504,   60,   60,  501,  543,   60,   60,  500,
      543,  223,  226,  495,  225,  490,  227,   60,   60,  487,
      543,   60,   60,  484,  543,  483,  228,  480,   60,   60,
      229,  543,  479,   60,   60,  478,  543,  231,  232,  477,
      230,   60,   60,  476,  543,  475,   60,   60,  474,  543,

      473,   60,   60,  472,  543,   60,   60,  466,  543,  233,
       60,   60,  457,  543,  234,  235,  236,  456,  237,   60,
       60,  455,  543,   60,   60,  454,  543,   60,   60,  238,
      543,  453,  239,  240,   60,   60,  452,  543,   60,   60,
      451,  543,   60,   60,  450,  543,  113,  191,  449,  242,
      241,  245,   60,   60,  448,  543,  447,  244,  243,   60,
       60,  246,  543,   60,   60,  446,  543,   60,   60,  445,
      543,   60,   60,  444,  543,   60,   60,  443,  543,  442,
      441,  440,  294,  247,  439,   60,   60,  293,  543,   60,
       60,  438,  543,  295,   60,   60,  437,  543,   60,   60,

      436,  543,  296,   60,   60,  435,  543,   60,   60,  434,
      543,   60,   60,  433,  543,  297,   60,   60,  425,  543,
       60,   60,  413,  543,  298,  412,  299,  411,  300,   60,
       60,  410,  543,   60,   60,  409,  543,  301,   60,   60,
      408,  543,  407,  302,  304,   60,   60,  406,  543,   60,
       60,  405,  543,  404,  303,   60,   60,  403,  543,  402,
       60,   60,  401,  543,   60,   60,  400,  543,   60,   60,
      399,  543,  305,  307,  306,  398,   60,   60,  397,  543,
      310,  396,  395,  308,  309,  394,   60,   60,  393,  543,
       60,   60,  392,  543,  313,   60,   60,  391,  543,   60,

       60,  390,  543,   60,   60,  389,  543,  388,  314,  311,
      387,  386,  315,  312,   60,   60,  385,  543,   60,   60,
      384,  543,   60,   60,  383,  543,  382,  317,  373,  316,
       60,   60,  359,  543,   60,   60,  358,  543,   60,   60,
      357,  543,  356,  319,  355,   60,   60,  318,  543,   60,
       60,  354,  543,   60,   60,  353,  543,  352,   60,   60,
      360,  543,  351,  364,   60,   60,  363,  543,  350,  361,
      349,  362,   60,   60,  348,  543,   60,   60,  347,  543,
       60,   60,  346,  543,  345,  344,  365,   60,   60,  343,
      543,  342,  341,  366,   60,   60,  367,  543,  340,  368,

       60,   60,  339,  543,   60,   60,  338,  543,   60,   60,
      337,  543,   60,   60,  336,  543,  335,  370,   60,   60,
      334,  543,  369,   60,   60,  333,  543,  332,  331,  330,
      372,  371,   60,   60,  329,  543,  328,   60,   60,  327,
      543,   60,   60,  326,  543,  374,  375,  325,   60,   60,
      324,  543,   60,   60,  323,  543,   60,   60,  320,  543,
      214,  378,  292,  376,  377,   60,   60,  291,  543,   60,
       60,  290,  543,  289,  380,   60,   60,  288,  543,   60,
       60,  287,  543,  286,   60,   60,  379,  543,   60,   60,
      285,  543,   60,   60,  284,  543,   60,   60,  381,  543,

      283,  415,  282,   60,   60,  281,  543,  414,  418,   60,
       60,  280,  543,  279,  419,  416,  278,   60,   60,  417,
      543,   60,   60,  277,  543,   60,   60,  276,  543,   60,
       60,  275,  543,  420,   60,   60,  272,  543,  421,   60,
       60,  271,  543,   60,   60,  270,  543,   60,   60,  422,
      543,  269,   60,   60,  423,  543,  424,   60,   60,  426,
      543,   60,   60,  427,  543,   60,   60,  268,  543,  267,
      430,   60,   60,  266,  543,  265,  428,   60,   60,  262,
      543,  261,  429,  260,   60,   60,  431,  543,   60,   60,
      432,  543,  259,  458,   60,   60,  256,  543,  255,   60,

       60,  254,  543,   60,   60,  253,  543,  460,  461,  250,
      462,  459,   60,   60,  249,  543,   60,   60,  248,  543,
       60,   60,   66,  543,  138,   60,   60,  463,  543,   60,
       60,  138,  543,   60,   60,  214,  543,  213,  465,   60,
       60,  212,  543,  211,   60,   60,  464,  543,  467,   60,
       60,  210,  543,   60,   60,  209,  543,   60,   60,  206,
      543,   60,   60,  205,  543,   60,   60,  204,  543,  203,
      468,   60,   60,  200,  543,   60,   60,  199,  543,  198,
      469,  471,  195,  194,  491,  470,   60,   60,  193,  543,
       60,   60,  192,  543,   60,   60,  189,  543,   60,   60,

      188,  543,  180,  493,  492,   60,   60,  177,  543,   60,
       60,  171,  543,   60,   60,  494,  543,   60,   60,  170,
      543,   60,   60,  133,  543,   60,   60,  496,  543,   60,
       60,  125,  543,  117,  498,  116,   60,   60,  499,  543,
       60,   60,  115,  543,  106,  497,   60,   60,  107,  543,
       60,   60,  106,  543,   49,   60,   60,  512,  543,   60,
       60,  543,  543,   60,   60,  543,  543,   60,   60,  543,
      543,   60,   60,  543,  543,   60,   60,  543,  543,  543,
      513,  543,   60,   60,  521,  543,   38,   38,   38,   38,
       42,   42,   42,   42,   65,   65,  103,  103,  103,  103,

      108,  543,  108,  108,  109,  543,  109,  109,  112,  112,
      112,  112,  190,  190,  190,  190,  481,  543,  481,  481,
      482,  543,  482,  482,    7,  543,  543,  543,  543,  543,
      543,  543,  543,  543,  543,  543,  543,  543,  543,  543,
      543,  543,  543,  543,  543,  543,  543,  543,  543,  543,
      543,  543,  543,  543,  543,  543,  543,  543,  543,  543,
      543,  543,  543,  543,  543,  543
    } ;

static yyconst flex_int16_t yy_chk[1267] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    2,    2,    3,    3,  552,    3,    4,    4,  546,
        4,    4,    5,    5,    6,    6,    9,    6,    6,    9,
       12,   13,   12,   13,   12,   15,   16,   15,   12,   37,
       37,   12,   12,   16,   18,   44,   18,   12,   20,   20,
      540,   20,   48,   12,   20,   48,   21,   21,  539,   21,
       22,   22,   44,   22,   16,   21,   23,   23,   53,   23,

       24,   24,  119,   24,   53,   23,   25,   25,   22,   25,
      128,   24,   26,   26,  119,   26,   27,   27,   59,   27,
       59,   26,  128,   28,   28,   27,   28,   29,   29,   62,
       29,   62,   29,   30,   30,   98,   30,   56,   30,   56,
       28,   98,   35,   35,   30,   35,   28,   31,   31,  538,
       31,   30,   45,   45,   58,   56,   31,   32,   32,  537,
       32,   58,   34,   34,  123,   34,   32,   34,   32,   32,
      123,   61,   64,  536,   64,   32,  535,   64,   61,   52,
       32,   32,   58,   52,   32,   33,   33,   52,   33,   52,
       33,  451,   52,   55,   33,  178,   55,   55,   33,   61,

       63,  178,   65,   65,   55,   65,  173,   63,   66,   66,
       66,   66,   33,   36,   67,   67,  451,   67,  173,   67,
      534,   68,   68,   36,   68,   36,   68,   36,   63,  532,
       36,   36,   93,   93,   36,   36,   67,  530,   66,  528,
       36,   69,   69,  101,   69,  101,   36,  527,   70,   70,
      194,   70,   71,   71,  455,   71,  194,   69,   70,   72,
       72,  101,   72,   73,   73,  134,   73,  455,   74,   74,
       73,   74,  134,   71,   75,   75,   72,   75,   76,   76,
      525,   76,  524,   75,  183,   78,   78,   74,   78,   77,
       77,   74,   77,  134,   79,   79,  183,   79,  103,  103,

      474,   76,   79,  105,  105,   77,   78,   80,   80,  523,
       80,   77,   81,   81,  522,   81,  478,   82,   82,   81,
       82,  520,   80,   83,   83,  474,   83,   84,   84,  478,
       84,  135,   83,  135,   85,   85,  135,   85,   82,  110,
      110,  519,   84,   85,   86,   86,  518,   86,   87,   87,
       86,   87,   88,   88,  517,   88,   89,   89,   88,   89,
       90,   90,  249,   90,  516,   86,   91,   91,  249,   91,
       87,  515,   89,  511,   92,   92,   90,   92,   96,  112,
      112,  510,   96,  114,  114,   91,   96,  509,   96,   92,
      100,   96,  506,  100,  100,  140,  140,  505,  140,  141,

      141,  100,  141,  142,  142,  503,  142,  143,  143,  502,
      143,  144,  144,  501,  144,  140,  500,  141,  489,  142,
      145,  145,  488,  145,  144,  486,  143,  146,  146,  485,
      146,  147,  147,  484,  147,  483,  146,  148,  148,  145,
      148,  149,  149,  479,  149,  190,  190,  147,  150,  150,
      149,  150,  476,  151,  151,  473,  151,  153,  153,  472,
      153,  148,  151,  466,  150,  456,  151,  152,  152,  453,
      152,  154,  154,  450,  154,  449,  152,  444,  155,  155,
      153,  155,  442,  156,  156,  441,  156,  155,  156,  440,
      154,  157,  157,  438,  157,  437,  158,  158,  435,  158,

      434,  159,  159,  433,  159,  160,  160,  425,  160,  157,
      161,  161,  411,  161,  157,  158,  159,  409,  160,  162,
      162,  408,  162,  163,  163,  407,  163,  164,  164,  161,
      164,  406,  162,  163,  165,  165,  405,  165,  166,  166,
      403,  166,  167,  167,  402,  167,  191,  191,  401,  165,
      164,  167,  168,  168,  400,  168,  399,  166,  165,  169,
      169,  168,  169,  215,  215,  398,  215,  216,  216,  397,
      216,  217,  217,  396,  217,  218,  218,  395,  218,  392,
      391,  390,  216,  169,  389,  219,  219,  215,  219,  220,
      220,  388,  220,  218,  221,  221,  387,  221,  222,  222,

      386,  222,  219,  223,  223,  384,  223,  224,  224,  383,
      224,  225,  225,  382,  225,  221,  226,  226,  373,  226,
      227,  227,  359,  227,  222,  358,  223,  357,  224,  228,
      228,  356,  228,  229,  229,  353,  229,  226,  230,  230,
      352,  230,  351,  227,  231,  231,  231,  350,  231,  232,
      232,  349,  232,  348,  229,  233,  233,  346,  233,  345,
      234,  234,  344,  234,  235,  235,  343,  235,  236,  236,
      342,  236,  232,  234,  233,  340,  237,  237,  339,  237,
      238,  338,  336,  236,  237,  334,  238,  238,  333,  238,
      239,  239,  332,  239,  240,  240,  240,  330,  240,  241,

      241,  329,  241,  242,  242,  328,  242,  327,  241,  238,
      326,  325,  242,  239,  243,  243,  323,  243,  244,  244,
      322,  244,  245,  245,  321,  245,  320,  244,  310,  243,
      246,  246,  291,  246,  247,  247,  290,  247,  293,  293,
      289,  293,  287,  247,  285,  294,  294,  245,  294,  295,
      295,  284,  295,  296,  296,  283,  296,  281,  297,  297,
      293,  297,  280,  297,  298,  298,  296,  298,  279,  294,
      278,  295,  299,  299,  277,  299,  300,  300,  275,  300,
      301,  301,  274,  301,  273,  272,  300,  302,  302,  271,
      302,  270,  269,  301,  303,  303,  302,  303,  268,  303,

      304,  304,  267,  304,  305,  305,  266,  305,  306,  306,
      265,  306,  307,  307,  264,  307,  263,  305,  308,  308,
      262,  308,  304,  309,  309,  261,  309,  260,  259,  258,
      307,  306,  311,  311,  257,  311,  256,  312,  312,  255,
      312,  313,  313,  253,  313,  311,  312,  252,  314,  314,
      251,  314,  315,  315,  250,  315,  316,  316,  248,  316,
      214,  316,  213,  313,  314,  317,  317,  212,  317,  318,
      318,  211,  318,  210,  318,  319,  319,  209,  319,  360,
      360,  208,  360,  207,  361,  361,  317,  361,  362,  362,
      206,  362,  363,  363,  205,  363,  364,  364,  319,  364,

      204,  362,  203,  365,  365,  202,  365,  361,  365,  366,
      366,  201,  366,  200,  366,  363,  198,  367,  367,  364,
      367,  368,  368,  197,  368,  369,  369,  196,  369,  370,
      370,  195,  370,  367,  371,  371,  193,  371,  368,  372,
      372,  192,  372,  374,  374,  189,  374,  375,  375,  369,
      375,  188,  376,  376,  370,  376,  372,  377,  377,  374,
      377,  378,  378,  375,  378,  379,  379,  187,  379,  186,
      379,  380,  380,  185,  380,  184,  376,  381,  381,  182,
      381,  181,  378,  180,  414,  414,  380,  414,  415,  415,
      381,  415,  179,  414,  416,  416,  177,  416,  176,  417,

      417,  175,  417,  418,  418,  174,  418,  416,  417,  172,
      418,  415,  419,  419,  171,  419,  420,  420,  170,  420,
      421,  421,  139,  421,  138,  422,  422,  419,  422,  423,
      423,  137,  423,  424,  424,  136,  424,  133,  423,  426,
      426,  132,  426,  131,  427,  427,  422,  427,  426,  428,
      428,  130,  428,  429,  429,  129,  429,  430,  430,  127,
      430,  431,  431,  126,  431,  432,  432,  125,  432,  124,
      428,  458,  458,  122,  458,  459,  459,  121,  459,  120,
      430,  432,  118,  117,  459,  431,  460,  460,  116,  460,
      461,  461,  111,  461,  462,  462,  107,  462,  463,  463,

      102,  463,   99,  462,  460,  464,  464,   97,  464,  465,
      465,   95,  465,  467,  467,  464,  467,  468,  468,   94,
      468,  469,  469,   57,  469,  470,  470,  468,  470,  471,
      471,   54,  471,   51,  470,   50,  491,  491,  471,  491,
      492,  492,   47,  492,   43,  469,  493,  493,   41,  493,
      494,  494,   40,  494,   11,  496,  496,  492,  496,  497,
      497,    7,  497,  498,  498,    0,  498,  499,  499,    0,
      499,  512,  512,    0,  512,  513,  513,    0,  513,    0,
      497,    0,  521,  521,  513,  521,  544,  544,  544,  544,
      545,  545,  545,  545,  547,  547,  548,  548,  548,  548,

      549,    0,  549,  549,  550,    0,  550,  550,  551,  551,
      551,  551,  553,  553,  553,  553,  554,    0,  554,  554,
      555,    0,  555,  555,  543,  543,  543,  543,  543,  543,
      543,  543,  543,  543,  543,  543,  543,  543,  543,  543,
      543,  543,  543,  543,  543,  543,  543,  543,  543,  543,
      543,  543,  543,  543,  543,  543,  543,  543,  543,  543,
      543,  543,  543,  543,  543,  543
    } ;

static yy_state_type yy_last_accepting_state;
static char *yy_last_accepting_cpos;

extern int HECMW_hec_flex_debug;
int HECMW_hec_flex_debug = 0;

/* The intent behind this definition is that it'll catch
 * any uses of REJECT which flex missed.
 */
#define REJECT reject_used_but_not_detected
#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
char *HECMW_hectext;
#line 1 "../src/common/hecmw_heclex.l"
#line 2 "../src/common/hecmw_heclex.l"
#include <string.h>
#include <errno.h>
#include "hecmw_heclex.h"
#include "hecmw_util.h"

typedef union {
	double dval;
	char *str;
} YYSTYPE;

static YYSTYPE yylval;
static int lineno;
static int lineno_inc;
static int flag_including = 0;
static FILE *incfp;
static char include_filename[HECMW_FILENAME_LEN+1];
static YY_BUFFER_STATE prev_state;
static int flag_header;

static void set_flag_header(int flag);


#line 951 "<stdout>"

#define INITIAL 0
#define HEADER 1
#define INCLUDE 2

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

static int yy_init_globals (void );

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int HECMW_heclex_destroy (void );

int HECMW_hecget_debug (void );

void HECMW_hecset_debug (int debug_flag  );

YY_EXTRA_TYPE HECMW_hecget_extra (void );

void HECMW_hecset_extra (YY_EXTRA_TYPE user_defined  );

FILE *HECMW_hecget_in (void );

void HECMW_hecset_in  (FILE * in_str  );

FILE *HECMW_hecget_out (void );

void HECMW_hecset_out  (FILE * out_str  );

yy_size_t HECMW_hecget_leng (void );

char *HECMW_hecget_text (void );

int HECMW_hecget_lineno (void );

void HECMW_hecset_lineno (int line_number  );

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int HECMW_hecwrap (void );
#else
extern int HECMW_hecwrap (void );
#endif
#endif

#ifndef yytext_ptr
static void yy_flex_strncpy (char *,yyconst char *,int );
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * );
#endif

#ifndef YY_NO_INPUT

#ifdef __cplusplus
static int yyinput (void );
#else
static int input (void );
#endif

#endif

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#define YY_READ_BUF_SIZE 8192
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO fwrite( HECMW_hectext, HECMW_hecleng, 1, HECMW_hecout )
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		yy_size_t n; \
		for ( n = 0; n < max_size && \
			     (c = getc( HECMW_hecin )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( HECMW_hecin ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = fread(buf, 1, max_size, HECMW_hecin))==0 && ferror(HECMW_hecin)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(HECMW_hecin); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg )
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int HECMW_heclex (void);

#define YY_DECL int HECMW_heclex (void)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after HECMW_hectext and HECMW_hecleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK break;
#endif

#define YY_RULE_SETUP \
	if ( HECMW_hecleng > 0 ) \
		YY_CURRENT_BUFFER_LVALUE->yy_at_bol = \
				(HECMW_hectext[HECMW_hecleng - 1] == '\n'); \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	register yy_state_type yy_current_state;
	register char *yy_cp, *yy_bp;
	register int yy_act;
    
#line 38 "../src/common/hecmw_heclex.l"


#line 1139 "<stdout>"

	if ( !(yy_init) )
		{
		(yy_init) = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

		if ( ! (yy_start) )
			(yy_start) = 1;	/* first start state */

		if ( ! HECMW_hecin )
			HECMW_hecin = stdin;

		if ( ! HECMW_hecout )
			HECMW_hecout = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			HECMW_hecensure_buffer_stack ();
			YY_CURRENT_BUFFER_LVALUE =
				HECMW_hec_create_buffer(HECMW_hecin,YY_BUF_SIZE );
		}

		HECMW_hec_load_buffer_state( );
		}

	while ( 1 )		/* loops until end-of-file is reached */
		{
		yy_cp = (yy_c_buf_p);

		/* Support of HECMW_hectext. */
		*yy_cp = (yy_hold_char);

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = (yy_start);
		yy_current_state += YY_AT_BOL();
yy_match:
		do
			{
			register YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)];
			if ( yy_accept[yy_current_state] )
				{
				(yy_last_accepting_state) = yy_current_state;
				(yy_last_accepting_cpos) = yy_cp;
				}
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 544 )
					yy_c = yy_meta[(unsigned int) yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
			++yy_cp;
			}
		while ( yy_base[yy_current_state] != 1225 );

yy_find_action:
		yy_act = yy_accept[yy_current_state];
		if ( yy_act == 0 )
			{ /* have to back up */
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			yy_act = yy_accept[yy_current_state];
			}

		YY_DO_BEFORE_ACTION;

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
			case 0: /* must back up */
			/* undo the effects of YY_DO_BEFORE_ACTION */
			*yy_cp = (yy_hold_char);
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			goto yy_find_action;

case 1:
/* rule 1 can match eol */
YY_RULE_SETUP
#line 40 "../src/common/hecmw_heclex.l"
{ lineno++; set_flag_header(0); }
	YY_BREAK
case 2:
/* rule 2 can match eol */
YY_RULE_SETUP
#line 41 "../src/common/hecmw_heclex.l"
{ lineno++; set_flag_header(0); }
	YY_BREAK
case 3:
YY_RULE_SETUP
#line 42 "../src/common/hecmw_heclex.l"
{ return flag_header ? HECMW_HECLEX_H_HEADER : ' '; }
	YY_BREAK
case 4:
YY_RULE_SETUP
#line 43 "../src/common/hecmw_heclex.l"
{
						HECMW_heclex_unput_token();
						set_flag_header(1);
						BEGIN INITIAL;
					}
	YY_BREAK
case 5:
YY_RULE_SETUP
#line 48 "../src/common/hecmw_heclex.l"
{ set_flag_header(0); return HECMW_HECLEX_HEADER; }
	YY_BREAK
case 6:
/* rule 6 can match eol */
YY_RULE_SETUP
#line 50 "../src/common/hecmw_heclex.l"
{ lineno_inc++; set_flag_header(0); return HECMW_HECLEX_NL; }
	YY_BREAK
case YY_STATE_EOF(INCLUDE):
#line 51 "../src/common/hecmw_heclex.l"
{
						HECMW_hec_delete_buffer(YY_CURRENT_BUFFER);
						HECMW_hec_switch_to_buffer(prev_state);
						if(fclose(incfp)) {
							HECMW_set_error(HECMW_IO_E0006,
								"File: %s, %s", include_filename, strerror(errno));
						}
						flag_including = 0;
						BEGIN INITIAL;
					}
	YY_BREAK
case 7:
/* rule 7 can match eol */
YY_RULE_SETUP
#line 62 "../src/common/hecmw_heclex.l"
{ lineno++; set_flag_header(0); }
	YY_BREAK
case 8:
YY_RULE_SETUP
#line 63 "../src/common/hecmw_heclex.l"
{ set_flag_header(0); }
	YY_BREAK
case 9:
/* rule 9 can match eol */
YY_RULE_SETUP
#line 64 "../src/common/hecmw_heclex.l"
{ lineno++; set_flag_header(0); return HECMW_HECLEX_NL; }
	YY_BREAK
case 10:
YY_RULE_SETUP
#line 66 "../src/common/hecmw_heclex.l"
{ set_flag_header(1); return HECMW_HECLEX_H_AMPLITUDE; }
	YY_BREAK
case 11:
YY_RULE_SETUP
#line 67 "../src/common/hecmw_heclex.l"
{ return flag_header ? HECMW_HECLEX_H_AMPLITUDE : ' '; }
	YY_BREAK
case 12:
YY_RULE_SETUP
#line 68 "../src/common/hecmw_heclex.l"
{ set_flag_header(1); return HECMW_HECLEX_H_CONNECTIVITY; }
	YY_BREAK
case 13:
YY_RULE_SETUP
#line 69 "../src/common/hecmw_heclex.l"
{ return flag_header ? HECMW_HECLEX_H_CONNECTIVITY : ' '; }
	YY_BREAK
case 14:
YY_RULE_SETUP
#line 70 "../src/common/hecmw_heclex.l"
{ set_flag_header(1); return HECMW_HECLEX_H_CONTACT_PAIR; }
	YY_BREAK
case 15:
YY_RULE_SETUP
#line 71 "../src/common/hecmw_heclex.l"
{ return flag_header ? HECMW_HECLEX_H_CONTACT_PAIR : ' '; }
	YY_BREAK
case 16:
YY_RULE_SETUP
#line 72 "../src/common/hecmw_heclex.l"
{ set_flag_header(1); return HECMW_HECLEX_H_ECOPY; }
	YY_BREAK
case 17:
YY_RULE_SETUP
#line 73 "../src/common/hecmw_heclex.l"
{ return flag_header ? HECMW_HECLEX_H_ECOPY : ' '; }
	YY_BREAK
case 18:
YY_RULE_SETUP
#line 74 "../src/common/hecmw_heclex.l"
{ set_flag_header(1); return HECMW_HECLEX_H_EGEN; }
	YY_BREAK
case 19:
YY_RULE_SETUP
#line 75 "../src/common/hecmw_heclex.l"
{ return flag_header ? HECMW_HECLEX_H_EGEN : ' '; }
	YY_BREAK
case 20:
YY_RULE_SETUP
#line 76 "../src/common/hecmw_heclex.l"
{ set_flag_header(1); return HECMW_HECLEX_H_EGROUP; }
	YY_BREAK
case 21:
YY_RULE_SETUP
#line 77 "../src/common/hecmw_heclex.l"
{ return flag_header ? HECMW_HECLEX_H_EGROUP : ' '; }
	YY_BREAK
case 22:
YY_RULE_SETUP
#line 78 "../src/common/hecmw_heclex.l"
{ set_flag_header(1); return HECMW_HECLEX_H_ELEMENT; }
	YY_BREAK
case 23:
YY_RULE_SETUP
#line 79 "../src/common/hecmw_heclex.l"
{ return flag_header ? HECMW_HECLEX_H_ELEMENT : ' '; }
	YY_BREAK
case 24:
YY_RULE_SETUP
#line 80 "../src/common/hecmw_heclex.l"
{ set_flag_header(1); return HECMW_HECLEX_H_END; }
	YY_BREAK
case 25:
YY_RULE_SETUP
#line 81 "../src/common/hecmw_heclex.l"
{ return flag_header ? HECMW_HECLEX_H_END : ' '; }
	YY_BREAK
case 26:
YY_RULE_SETUP
#line 82 "../src/common/hecmw_heclex.l"
{ set_flag_header(1); return HECMW_HECLEX_H_EQUATION; }
	YY_BREAK
case 27:
YY_RULE_SETUP
#line 83 "../src/common/hecmw_heclex.l"
{ return flag_header ? HECMW_HECLEX_H_EQUATION : ' '; }
	YY_BREAK
case 28:
YY_RULE_SETUP
#line 84 "../src/common/hecmw_heclex.l"
{
				BEGIN HEADER;
				set_flag_header(1);
				return HECMW_HECLEX_H_HEADER;
			}
	YY_BREAK
case 29:
YY_RULE_SETUP
#line 89 "../src/common/hecmw_heclex.l"
{ set_flag_header(1); return HECMW_HECLEX_H_INCLUDE; }
	YY_BREAK
case 30:
YY_RULE_SETUP
#line 90 "../src/common/hecmw_heclex.l"
{ return flag_header ? HECMW_HECLEX_H_INCLUDE : ' '; }
	YY_BREAK
case 31:
YY_RULE_SETUP
#line 91 "../src/common/hecmw_heclex.l"
{
							set_flag_header(1);
							return HECMW_HECLEX_H_INITIAL;
						}
	YY_BREAK
case 32:
YY_RULE_SETUP
#line 95 "../src/common/hecmw_heclex.l"
{
							return flag_header ? HECMW_HECLEX_H_INITIAL : ' ';
						}
	YY_BREAK
case 33:
YY_RULE_SETUP
#line 98 "../src/common/hecmw_heclex.l"
{ set_flag_header(1); return HECMW_HECLEX_H_ITEM; }
	YY_BREAK
case 34:
YY_RULE_SETUP
#line 99 "../src/common/hecmw_heclex.l"
{ return flag_header ? HECMW_HECLEX_H_ITEM : ' '; }
	YY_BREAK
case 35:
YY_RULE_SETUP
#line 100 "../src/common/hecmw_heclex.l"
{ set_flag_header(1); return HECMW_HECLEX_H_MATERIAL; }
	YY_BREAK
case 36:
YY_RULE_SETUP
#line 101 "../src/common/hecmw_heclex.l"
{ return flag_header ? HECMW_HECLEX_H_MATERIAL : ' '; }
	YY_BREAK
case 37:
YY_RULE_SETUP
#line 102 "../src/common/hecmw_heclex.l"
{ set_flag_header(1); return HECMW_HECLEX_H_NCOPY; }
	YY_BREAK
case 38:
YY_RULE_SETUP
#line 103 "../src/common/hecmw_heclex.l"
{ return flag_header ? HECMW_HECLEX_H_NCOPY : ' '; }
	YY_BREAK
case 39:
YY_RULE_SETUP
#line 104 "../src/common/hecmw_heclex.l"
{ set_flag_header(1); return HECMW_HECLEX_H_NFILL; }
	YY_BREAK
case 40:
YY_RULE_SETUP
#line 105 "../src/common/hecmw_heclex.l"
{ return flag_header ? HECMW_HECLEX_H_NFILL : ' '; }
	YY_BREAK
case 41:
YY_RULE_SETUP
#line 106 "../src/common/hecmw_heclex.l"
{ set_flag_header(1); return HECMW_HECLEX_H_NGEN; }
	YY_BREAK
case 42:
YY_RULE_SETUP
#line 107 "../src/common/hecmw_heclex.l"
{ return flag_header ? HECMW_HECLEX_H_NGEN : ' '; }
	YY_BREAK
case 43:
YY_RULE_SETUP
#line 108 "../src/common/hecmw_heclex.l"
{ set_flag_header(1); return HECMW_HECLEX_H_NGROUP; }
	YY_BREAK
case 44:
YY_RULE_SETUP
#line 109 "../src/common/hecmw_heclex.l"
{ return flag_header ? HECMW_HECLEX_H_NGROUP : ' '; }
	YY_BREAK
case 45:
YY_RULE_SETUP
#line 110 "../src/common/hecmw_heclex.l"
{ set_flag_header(1); return HECMW_HECLEX_H_NODE; }
	YY_BREAK
case 46:
YY_RULE_SETUP
#line 111 "../src/common/hecmw_heclex.l"
{ return flag_header ? HECMW_HECLEX_H_NODE : ' '; }
	YY_BREAK
case 47:
YY_RULE_SETUP
#line 112 "../src/common/hecmw_heclex.l"
{ set_flag_header(1); return HECMW_HECLEX_H_SECTION; }
	YY_BREAK
case 48:
YY_RULE_SETUP
#line 113 "../src/common/hecmw_heclex.l"
{ return flag_header ? HECMW_HECLEX_H_SECTION : ' '; }
	YY_BREAK
case 49:
YY_RULE_SETUP
#line 114 "../src/common/hecmw_heclex.l"
{ set_flag_header(1); return HECMW_HECLEX_H_SGROUP; }
	YY_BREAK
case 50:
YY_RULE_SETUP
#line 115 "../src/common/hecmw_heclex.l"
{ return flag_header ? HECMW_HECLEX_H_SGROUP : ' '; }
	YY_BREAK
case 51:
YY_RULE_SETUP
#line 116 "../src/common/hecmw_heclex.l"
{ set_flag_header(1); return HECMW_HECLEX_H_SYSTEM; }
	YY_BREAK
case 52:
YY_RULE_SETUP
#line 117 "../src/common/hecmw_heclex.l"
{ return flag_header ? HECMW_HECLEX_H_SYSTEM : ' '; }
	YY_BREAK
case 53:
YY_RULE_SETUP
#line 118 "../src/common/hecmw_heclex.l"
{ set_flag_header(1); return HECMW_HECLEX_H_ZERO; }
	YY_BREAK
case 54:
YY_RULE_SETUP
#line 119 "../src/common/hecmw_heclex.l"
{ return flag_header ? HECMW_HECLEX_H_ZERO : ' '; }
	YY_BREAK
case 55:
YY_RULE_SETUP
#line 122 "../src/common/hecmw_heclex.l"
{ set_flag_header(0); return HECMW_HECLEX_K_ABAQUS; }
	YY_BREAK
case 56:
YY_RULE_SETUP
#line 123 "../src/common/hecmw_heclex.l"
{ set_flag_header(0); return HECMW_HECLEX_K_ABSOLUTE; }
	YY_BREAK
case 57:
YY_RULE_SETUP
#line 124 "../src/common/hecmw_heclex.l"
{ set_flag_header(0); return HECMW_HECLEX_K_BEAM; }
	YY_BREAK
case 58:
YY_RULE_SETUP
#line 125 "../src/common/hecmw_heclex.l"
{ set_flag_header(0); return HECMW_HECLEX_K_COMPOSITE; }
	YY_BREAK
case 59:
YY_RULE_SETUP
#line 126 "../src/common/hecmw_heclex.l"
{ set_flag_header(0); return HECMW_HECLEX_K_DEFINITION; }
	YY_BREAK
case 60:
YY_RULE_SETUP
#line 127 "../src/common/hecmw_heclex.l"
{ set_flag_header(0); return HECMW_HECLEX_K_EGRP; }
	YY_BREAK
case 61:
YY_RULE_SETUP
#line 128 "../src/common/hecmw_heclex.l"
{ set_flag_header(0); return HECMW_HECLEX_K_GENERATE; }
	YY_BREAK
case 62:
YY_RULE_SETUP
#line 129 "../src/common/hecmw_heclex.l"
{ set_flag_header(0); return HECMW_HECLEX_K_HECMW; }
	YY_BREAK
case 63:
YY_RULE_SETUP
#line 130 "../src/common/hecmw_heclex.l"
{ set_flag_header(0); return HECMW_HECLEX_K_INPUT; }
	YY_BREAK
case 64:
YY_RULE_SETUP
#line 131 "../src/common/hecmw_heclex.l"
{ set_flag_header(0); return HECMW_HECLEX_K_INTERFACE; }
	YY_BREAK
case 65:
YY_RULE_SETUP
#line 132 "../src/common/hecmw_heclex.l"
{ set_flag_header(0); return HECMW_HECLEX_K_ITEM; }
	YY_BREAK
case 66:
YY_RULE_SETUP
#line 133 "../src/common/hecmw_heclex.l"
{ set_flag_header(0); return HECMW_HECLEX_K_MATERIAL; }
	YY_BREAK
case 67:
YY_RULE_SETUP
#line 134 "../src/common/hecmw_heclex.l"
{ set_flag_header(0); return HECMW_HECLEX_K_MATITEM; }
	YY_BREAK
case 68:
YY_RULE_SETUP
#line 135 "../src/common/hecmw_heclex.l"
{ set_flag_header(0); return HECMW_HECLEX_K_NAME; }
	YY_BREAK
case 69:
YY_RULE_SETUP
#line 136 "../src/common/hecmw_heclex.l"
{ set_flag_header(0); return HECMW_HECLEX_K_NASTRAN; }
	YY_BREAK
case 70:
YY_RULE_SETUP
#line 137 "../src/common/hecmw_heclex.l"
{ set_flag_header(0); return HECMW_HECLEX_K_NGRP; }
	YY_BREAK
case 71:
YY_RULE_SETUP
#line 138 "../src/common/hecmw_heclex.l"
{ set_flag_header(0); return HECMW_HECLEX_K_NODE_SURF; }
	YY_BREAK
case 72:
YY_RULE_SETUP
#line 139 "../src/common/hecmw_heclex.l"
{ set_flag_header(0); return HECMW_HECLEX_K_RELATIVE; }
	YY_BREAK
case 73:
YY_RULE_SETUP
#line 140 "../src/common/hecmw_heclex.l"
{ set_flag_header(0); return HECMW_HECLEX_K_SECOPT; }
	YY_BREAK
case 74:
YY_RULE_SETUP
#line 141 "../src/common/hecmw_heclex.l"
{ set_flag_header(0); return HECMW_HECLEX_K_SECTION; }
	YY_BREAK
case 75:
YY_RULE_SETUP
#line 142 "../src/common/hecmw_heclex.l"
{ set_flag_header(0); return HECMW_HECLEX_K_SGRP; }
	YY_BREAK
case 76:
YY_RULE_SETUP
#line 143 "../src/common/hecmw_heclex.l"
{ set_flag_header(0); return HECMW_HECLEX_K_SHELL; }
	YY_BREAK
case 77:
YY_RULE_SETUP
#line 144 "../src/common/hecmw_heclex.l"
{ set_flag_header(0); return HECMW_HECLEX_K_SOLID; }
	YY_BREAK
case 78:
YY_RULE_SETUP
#line 145 "../src/common/hecmw_heclex.l"
{ set_flag_header(0); return HECMW_HECLEX_K_STEP_TIME; }
	YY_BREAK
case 79:
YY_RULE_SETUP
#line 146 "../src/common/hecmw_heclex.l"
{ set_flag_header(0); return HECMW_HECLEX_K_SUBITEM; }
	YY_BREAK
case 80:
YY_RULE_SETUP
#line 147 "../src/common/hecmw_heclex.l"
{ set_flag_header(0); return HECMW_HECLEX_K_SURF_SURF; }
	YY_BREAK
case 81:
YY_RULE_SETUP
#line 148 "../src/common/hecmw_heclex.l"
{ set_flag_header(0); return HECMW_HECLEX_K_SYSTEM; }
	YY_BREAK
case 82:
YY_RULE_SETUP
#line 149 "../src/common/hecmw_heclex.l"
{ set_flag_header(0); return HECMW_HECLEX_K_TABLE; }
	YY_BREAK
case 83:
YY_RULE_SETUP
#line 150 "../src/common/hecmw_heclex.l"
{ set_flag_header(0); return HECMW_HECLEX_K_TABULAR; }
	YY_BREAK
case 84:
YY_RULE_SETUP
#line 151 "../src/common/hecmw_heclex.l"
{ set_flag_header(0); return HECMW_HECLEX_K_TEMPERATURE; }
	YY_BREAK
case 85:
YY_RULE_SETUP
#line 152 "../src/common/hecmw_heclex.l"
{ set_flag_header(0); return HECMW_HECLEX_K_TIME; }
	YY_BREAK
case 86:
YY_RULE_SETUP
#line 153 "../src/common/hecmw_heclex.l"
{ set_flag_header(0); return HECMW_HECLEX_K_TYPE; }
	YY_BREAK
case 87:
YY_RULE_SETUP
#line 154 "../src/common/hecmw_heclex.l"
{ set_flag_header(0); return HECMW_HECLEX_K_VALUE; }
	YY_BREAK
case 88:
YY_RULE_SETUP
#line 155 "../src/common/hecmw_heclex.l"
{ set_flag_header(0); return HECMW_HECLEX_K_TIMEVALUE; }
	YY_BREAK
case 89:
YY_RULE_SETUP
#line 156 "../src/common/hecmw_heclex.l"
{ set_flag_header(0); return HECMW_HECLEX_K_VALUETIME; }
	YY_BREAK
case 90:
YY_RULE_SETUP
#line 158 "../src/common/hecmw_heclex.l"
{ set_flag_header(0); return '='; }
	YY_BREAK
case 91:
YY_RULE_SETUP
#line 159 "../src/common/hecmw_heclex.l"
{ set_flag_header(0); return ','; }
	YY_BREAK
case 92:
YY_RULE_SETUP
#line 160 "../src/common/hecmw_heclex.l"
{ set_flag_header(0); return 'C'; }
	YY_BREAK
case 93:
YY_RULE_SETUP
#line 161 "../src/common/hecmw_heclex.l"
{ set_flag_header(0); return 'R'; }
	YY_BREAK
case 94:
YY_RULE_SETUP
#line 163 "../src/common/hecmw_heclex.l"
{
				yylval.dval = atof(HECMW_hectext);
				set_flag_header(0);
				return HECMW_HECLEX_INT;
			}
	YY_BREAK
case 95:
YY_RULE_SETUP
#line 168 "../src/common/hecmw_heclex.l"
{
				yylval.dval = atof(HECMW_hectext);
				set_flag_header(0);
				return HECMW_HECLEX_DOUBLE;
			}
	YY_BREAK
case 96:
YY_RULE_SETUP
#line 173 "../src/common/hecmw_heclex.l"
{
				yylval.str = HECMW_hectext;
				set_flag_header(0);
				return HECMW_HECLEX_NAME;
			}
	YY_BREAK
case 97:
YY_RULE_SETUP
#line 178 "../src/common/hecmw_heclex.l"
{
				yylval.str = HECMW_hectext;
				set_flag_header(0);
				return HECMW_HECLEX_FILENAME;
			}
	YY_BREAK
case 98:
YY_RULE_SETUP
#line 183 "../src/common/hecmw_heclex.l"
{ set_flag_header(0); return HECMW_hectext[0]; }
	YY_BREAK
case YY_STATE_EOF(INITIAL):
case YY_STATE_EOF(HEADER):
#line 184 "../src/common/hecmw_heclex.l"
{ return 0; }
	YY_BREAK
case 99:
YY_RULE_SETUP
#line 186 "../src/common/hecmw_heclex.l"
ECHO;
	YY_BREAK
#line 1770 "<stdout>"

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - (yytext_ptr)) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = (yy_hold_char);
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed HECMW_hecin at a new source and called
			 * HECMW_heclex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = HECMW_hecin;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( (yy_c_buf_p) <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			(yy_c_buf_p) = (yytext_ptr) + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state(  );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state );

			yy_bp = (yytext_ptr) + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++(yy_c_buf_p);
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = (yy_c_buf_p);
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer(  ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				(yy_did_buffer_switch_on_eof) = 0;

				if ( HECMW_hecwrap( ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * HECMW_hectext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					(yy_c_buf_p) = (yytext_ptr) + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				(yy_c_buf_p) =
					(yytext_ptr) + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				(yy_c_buf_p) =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)];

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
} /* end of HECMW_heclex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (void)
{
    	register char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	register char *source = (yytext_ptr);
	register int number_to_move, i;
	int ret_val;

	if ( (yy_c_buf_p) > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( (yy_c_buf_p) - (yytext_ptr) - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) ((yy_c_buf_p) - (yytext_ptr)) - 1;

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars) = 0;

	else
		{
			yy_size_t num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			/* just a shorter name for the current buffer */
			YY_BUFFER_STATE b = YY_CURRENT_BUFFER;

			int yy_c_buf_p_offset =
				(int) ((yy_c_buf_p) - b->yy_ch_buf);

			if ( b->yy_is_our_buffer )
				{
				yy_size_t new_size = b->yy_buf_size * 2;

				if ( new_size <= 0 )
					b->yy_buf_size += b->yy_buf_size / 8;
				else
					b->yy_buf_size *= 2;

				b->yy_ch_buf = (char *)
					/* Include room in for 2 EOB chars. */
					HECMW_hecrealloc((void *) b->yy_ch_buf,b->yy_buf_size + 2  );
				}
			else
				/* Can't grow it, we don't own it. */
				b->yy_ch_buf = 0;

			if ( ! b->yy_ch_buf )
				YY_FATAL_ERROR(
				"fatal error - scanner input buffer overflow" );

			(yy_c_buf_p) = &b->yy_ch_buf[yy_c_buf_p_offset];

			num_to_read = YY_CURRENT_BUFFER_LVALUE->yy_buf_size -
						number_to_move - 1;

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			(yy_n_chars), num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	if ( (yy_n_chars) == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			HECMW_hecrestart(HECMW_hecin  );
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if ((yy_size_t) ((yy_n_chars) + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		yy_size_t new_size = (yy_n_chars) + number_to_move + ((yy_n_chars) >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) HECMW_hecrealloc((void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf,new_size  );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
	}

	(yy_n_chars) += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] = YY_END_OF_BUFFER_CHAR;

	(yytext_ptr) = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (void)
{
	register yy_state_type yy_current_state;
	register char *yy_cp;
    
	yy_current_state = (yy_start);
	yy_current_state += YY_AT_BOL();

	for ( yy_cp = (yytext_ptr) + YY_MORE_ADJ; yy_cp < (yy_c_buf_p); ++yy_cp )
		{
		register YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		if ( yy_accept[yy_current_state] )
			{
			(yy_last_accepting_state) = yy_current_state;
			(yy_last_accepting_cpos) = yy_cp;
			}
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 544 )
				yy_c = yy_meta[(unsigned int) yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state )
{
	register int yy_is_jam;
    	register char *yy_cp = (yy_c_buf_p);

	register YY_CHAR yy_c = 1;
	if ( yy_accept[yy_current_state] )
		{
		(yy_last_accepting_state) = yy_current_state;
		(yy_last_accepting_cpos) = yy_cp;
		}
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 544 )
			yy_c = yy_meta[(unsigned int) yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
	yy_is_jam = (yy_current_state == 543);

	return yy_is_jam ? 0 : yy_current_state;
}

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (void)
#else
    static int input  (void)
#endif

{
	int c;
    
	*(yy_c_buf_p) = (yy_hold_char);

	if ( *(yy_c_buf_p) == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( (yy_c_buf_p) < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			/* This was really a NUL. */
			*(yy_c_buf_p) = '\0';

		else
			{ /* need more input */
			yy_size_t offset = (yy_c_buf_p) - (yytext_ptr);
			++(yy_c_buf_p);

			switch ( yy_get_next_buffer(  ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					HECMW_hecrestart(HECMW_hecin );

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( HECMW_hecwrap( ) )
						return 0;

					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput();
#else
					return input();
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					(yy_c_buf_p) = (yytext_ptr) + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) (yy_c_buf_p);	/* cast for 8-bit char's */
	*(yy_c_buf_p) = '\0';	/* preserve HECMW_hectext */
	(yy_hold_char) = *++(yy_c_buf_p);

	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = (c == '\n');

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * 
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void HECMW_hecrestart  (FILE * input_file )
{
    
	if ( ! YY_CURRENT_BUFFER ){
        HECMW_hecensure_buffer_stack ();
		YY_CURRENT_BUFFER_LVALUE =
            HECMW_hec_create_buffer(HECMW_hecin,YY_BUF_SIZE );
	}

	HECMW_hec_init_buffer(YY_CURRENT_BUFFER,input_file );
	HECMW_hec_load_buffer_state( );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * 
 */
    void HECMW_hec_switch_to_buffer  (YY_BUFFER_STATE  new_buffer )
{
    
	/* TODO. We should be able to replace this entire function body
	 * with
	 *		HECMW_hecpop_buffer_state();
	 *		HECMW_hecpush_buffer_state(new_buffer);
     */
	HECMW_hecensure_buffer_stack ();
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	HECMW_hec_load_buffer_state( );

	/* We don't actually know whether we did this switch during
	 * EOF (HECMW_hecwrap()) processing, but the only time this flag
	 * is looked at is after HECMW_hecwrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	(yy_did_buffer_switch_on_eof) = 1;
}

static void HECMW_hec_load_buffer_state  (void)
{
    	(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	(yytext_ptr) = (yy_c_buf_p) = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	HECMW_hecin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	(yy_hold_char) = *(yy_c_buf_p);
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * 
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE HECMW_hec_create_buffer  (FILE * file, int  size )
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) HECMW_hecalloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in HECMW_hec_create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) HECMW_hecalloc(b->yy_buf_size + 2  );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in HECMW_hec_create_buffer()" );

	b->yy_is_our_buffer = 1;

	HECMW_hec_init_buffer(b,file );

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with HECMW_hec_create_buffer()
 * 
 */
    void HECMW_hec_delete_buffer (YY_BUFFER_STATE  b )
{
    
	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		HECMW_hecfree((void *) b->yy_ch_buf  );

	HECMW_hecfree((void *) b  );
}

#ifndef __cplusplus
extern int isatty (int );
#endif /* __cplusplus */
    
/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a HECMW_hecrestart() or at EOF.
 */
    static void HECMW_hec_init_buffer  (YY_BUFFER_STATE  b, FILE * file )

{
	int oerrno = errno;
    
	HECMW_hec_flush_buffer(b );

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then HECMW_hec_init_buffer was _probably_
     * called from HECMW_hecrestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = file ? (isatty( fileno(file) ) > 0) : 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * 
 */
    void HECMW_hec_flush_buffer (YY_BUFFER_STATE  b )
{
    	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		HECMW_hec_load_buffer_state( );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  
 */
void HECMW_hecpush_buffer_state (YY_BUFFER_STATE new_buffer )
{
    	if (new_buffer == NULL)
		return;

	HECMW_hecensure_buffer_stack();

	/* This block is copied from HECMW_hec_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		(yy_buffer_stack_top)++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from HECMW_hec_switch_to_buffer. */
	HECMW_hec_load_buffer_state( );
	(yy_did_buffer_switch_on_eof) = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  
 */
void HECMW_hecpop_buffer_state (void)
{
    	if (!YY_CURRENT_BUFFER)
		return;

	HECMW_hec_delete_buffer(YY_CURRENT_BUFFER );
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if ((yy_buffer_stack_top) > 0)
		--(yy_buffer_stack_top);

	if (YY_CURRENT_BUFFER) {
		HECMW_hec_load_buffer_state( );
		(yy_did_buffer_switch_on_eof) = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void HECMW_hecensure_buffer_stack (void)
{
	yy_size_t num_to_alloc;
    
	if (!(yy_buffer_stack)) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
		num_to_alloc = 1;
		(yy_buffer_stack) = (struct yy_buffer_state**)HECMW_hecalloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in HECMW_hecensure_buffer_stack()" );
								  
		memset((yy_buffer_stack), 0, num_to_alloc * sizeof(struct yy_buffer_state*));
				
		(yy_buffer_stack_max) = num_to_alloc;
		(yy_buffer_stack_top) = 0;
		return;
	}

	if ((yy_buffer_stack_top) >= ((yy_buffer_stack_max)) - 1){

		/* Increase the buffer to prepare for a possible push. */
		int grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = (yy_buffer_stack_max) + grow_size;
		(yy_buffer_stack) = (struct yy_buffer_state**)HECMW_hecrealloc
								((yy_buffer_stack),
								num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in HECMW_hecensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset((yy_buffer_stack) + (yy_buffer_stack_max), 0, grow_size * sizeof(struct yy_buffer_state*));
		(yy_buffer_stack_max) = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * 
 * @return the newly allocated buffer state object. 
 */
YY_BUFFER_STATE HECMW_hec_scan_buffer  (char * base, yy_size_t  size )
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return 0;

	b = (YY_BUFFER_STATE) HECMW_hecalloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in HECMW_hec_scan_buffer()" );

	b->yy_buf_size = size - 2;	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = 0;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	HECMW_hec_switch_to_buffer(b  );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to HECMW_heclex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * 
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       HECMW_hec_scan_bytes() instead.
 */
YY_BUFFER_STATE HECMW_hec_scan_string (yyconst char * yystr )
{
    
	return HECMW_hec_scan_bytes(yystr,strlen(yystr) );
}

/** Setup the input buffer state to scan the given bytes. The next call to HECMW_heclex() will
 * scan from a @e copy of @a bytes.
 * @param bytes the byte buffer to scan
 * @param len the number of bytes in the buffer pointed to by @a bytes.
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE HECMW_hec_scan_bytes  (yyconst char * yybytes, yy_size_t  _yybytes_len )
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n, i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = _yybytes_len + 2;
	buf = (char *) HECMW_hecalloc(n  );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in HECMW_hec_scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = HECMW_hec_scan_buffer(buf,n );
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in HECMW_hec_scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yy_fatal_error (yyconst char* msg )
{
    	(void) fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up HECMW_hectext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		HECMW_hectext[HECMW_hecleng] = (yy_hold_char); \
		(yy_c_buf_p) = HECMW_hectext + yyless_macro_arg; \
		(yy_hold_char) = *(yy_c_buf_p); \
		*(yy_c_buf_p) = '\0'; \
		HECMW_hecleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the current line number.
 * 
 */
int HECMW_hecget_lineno  (void)
{
        
    return HECMW_heclineno;
}

/** Get the input stream.
 * 
 */
FILE *HECMW_hecget_in  (void)
{
        return HECMW_hecin;
}

/** Get the output stream.
 * 
 */
FILE *HECMW_hecget_out  (void)
{
        return HECMW_hecout;
}

/** Get the length of the current token.
 * 
 */
yy_size_t HECMW_hecget_leng  (void)
{
        return HECMW_hecleng;
}

/** Get the current token.
 * 
 */

char *HECMW_hecget_text  (void)
{
        return HECMW_hectext;
}

/** Set the current line number.
 * @param line_number
 * 
 */
void HECMW_hecset_lineno (int  line_number )
{
    
    HECMW_heclineno = line_number;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param in_str A readable stream.
 * 
 * @see HECMW_hec_switch_to_buffer
 */
void HECMW_hecset_in (FILE *  in_str )
{
        HECMW_hecin = in_str ;
}

void HECMW_hecset_out (FILE *  out_str )
{
        HECMW_hecout = out_str ;
}

int HECMW_hecget_debug  (void)
{
        return HECMW_hec_flex_debug;
}

void HECMW_hecset_debug (int  bdebug )
{
        HECMW_hec_flex_debug = bdebug ;
}

static int yy_init_globals (void)
{
        /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from HECMW_heclex_destroy(), so don't allocate here.
     */

    (yy_buffer_stack) = 0;
    (yy_buffer_stack_top) = 0;
    (yy_buffer_stack_max) = 0;
    (yy_c_buf_p) = (char *) 0;
    (yy_init) = 0;
    (yy_start) = 0;

/* Defined in main.c */
#ifdef YY_STDINIT
    HECMW_hecin = stdin;
    HECMW_hecout = stdout;
#else
    HECMW_hecin = (FILE *) 0;
    HECMW_hecout = (FILE *) 0;
#endif

    /* For future reference: Set errno on error, since we are called by
     * HECMW_heclex_init()
     */
    return 0;
}

/* HECMW_heclex_destroy is for both reentrant and non-reentrant scanners. */
int HECMW_heclex_destroy  (void)
{
    
    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		HECMW_hec_delete_buffer(YY_CURRENT_BUFFER  );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		HECMW_hecpop_buffer_state();
	}

	/* Destroy the stack itself. */
	HECMW_hecfree((yy_buffer_stack) );
	(yy_buffer_stack) = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * HECMW_heclex() is called, initialization will occur. */
    yy_init_globals( );

    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, yyconst char * s2, int n )
{
	register int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * s )
{
	register int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *HECMW_hecalloc (yy_size_t  size )
{
	return (void *) malloc( size );
}

void *HECMW_hecrealloc  (void * ptr, yy_size_t  size )
{
	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return (void *) realloc( (char *) ptr, size );
}

void HECMW_hecfree (void * ptr )
{
	free( (char *) ptr );	/* see HECMW_hecrealloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

#line 186 "../src/common/hecmw_heclex.l"



static void
set_flag_header(int flag)
{
	flag_header = flag ? 1 : 0;
}


int
HECMW_heclex_get_lineno(void)
{
	return flag_including ? lineno_inc : lineno;
}


double
HECMW_heclex_get_number(void)
{
	return yylval.dval;
}


char *
HECMW_heclex_get_text(void)
{
	return HECMW_hectext;
}


int
HECMW_heclex_is_including(void)
{
	return flag_including ? 1 : 0;
}


int
HECMW_heclex_next_token(void)
{
	return HECMW_heclex();
}


int
HECMW_heclex_next_token_skip(int skip_token)
{
	int token;
	while((token = HECMW_heclex())) {
		if(token != skip_token) break;
	}
	return token;
}


int
HECMW_heclex_set_input(FILE *fp)
{
	static int first = 1;
	if(fp == NULL) return -1;
	if(first) {
		HECMW_hecin = fp;
		first = 0;
	} else {
		HECMW_hecrestart(fp);
	}
	lineno = 1;
	return 0;
}


int
HECMW_heclex_skip_line(void)
{
	int token;
	while((token = HECMW_heclex_next_token())) {
		if(token == HECMW_HECLEX_NL) break;
	}
	return token;
}


int
HECMW_heclex_switch_to_include(const char *filename)
{
	if(filename == NULL) return -1;
	if(flag_including) {
		HECMW_set_error(HECMW_IO_E0004, "File: %s, %s", filename);
		return -1;
	}
	if((incfp = fopen(filename, "r")) == NULL) {
		HECMW_set_error(HECMW_IO_E0005, "File: %s, %s", filename, strerror(errno));
		return -1;
	}
	strcpy(include_filename, filename);
	prev_state = YY_CURRENT_BUFFER;
	HECMW_hec_switch_to_buffer(HECMW_hec_create_buffer(incfp,YY_BUF_SIZE));
	lineno_inc = 1;
	flag_including = 1;
	BEGIN INCLUDE;
	return 0;
}


int
HECMW_heclex_unput_token(void)
{
	char *p = HECMW_hectext;
	while(*p) {
		if(*p == '\n') {
			if(YYSTATE == INCLUDE) {
				lineno_inc--;
			} else {
				lineno--;
			}
		}
		p++;
	}
	yyless(0);
	return 0;
}


int
HECMW_hecwrap(void)
{
	return 1;
}



